@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-from . import cmdline
+from tileviewer import cmdline
 
 if __name__ == '__main__':
     cmdline.run()
